package huo;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.List;

import org.springframework.context.support.ClassPathXmlApplicationContext;


/**
 * <p>
 * Title: ConfigMyParameters
 * </p>
 * 
 * <p>
 * Contains properties mostly from the configuration file myparameters.properties.
 * </p>
 * 
 * @author Huseyin OZVEREN
 */
public class ConfigMyParameters {

	// ----------------------------------------------------- PRIVATE ATTRIBUTES
	/**
	 * Singleton instance
	 */
	private static ConfigMyParameters instance = null;

	/**
	 * Default mail domain
	 */
	private String defaultMailDomain = "";

	/**
	 * Contains the identity (email) used to send mails.
	 */
	private String smtpMailFrom = "";

	/**
	 * Smtp server host
	 */
	private String smtpMailhost = "";
	
	/**
	 * Smtp server port
	 */
	private String smtpMailport = "";
     
	/**
	 * Emails' list of administrators
	 */
	private List<String> mailAdministrators = new ArrayList<String>();
	
	// --------------------------------------------------------- PUBLIC METHODS
	/**
	 * @return an unique instance of the application configuration class.
	 */
	public static synchronized ConfigMyParameters getInstance() {
		if (null == instance) {
			String SPRING_FILE_NAME = "huo-spring-properties-config.xml";
			ClassPathXmlApplicationContext ctx = new ClassPathXmlApplicationContext(SPRING_FILE_NAME);
			instance = (ConfigMyParameters) ctx.getBean("ConfigMyParameters");
		} // end-if
		return instance;
	}
	
	// ------------------------------------------------------ GETTERS & SETTERS
	public String getDefaultMailDomain() {
		return defaultMailDomain;
	}

	public void setDefaultMailDomain(String defaultMailDomain) {
		this.defaultMailDomain = defaultMailDomain;
	}

	public String getSmtpMailFrom() {
		return smtpMailFrom;
	}

	public void setSmtpMailFrom(String smtpMailFrom) {
		this.smtpMailFrom = smtpMailFrom;
	}

	public String getSmtpMailhost() {
		return smtpMailhost;
	}

	public void setSmtpMailhost(String smtpMailhost) {
		this.smtpMailhost = smtpMailhost;
	}

	public String getSmtpMailport() {
		return smtpMailport;
	}

	public void setSmtpMailport(String smtpMailport) {
		this.smtpMailport = smtpMailport;
	}


	// --------------------------------------------------------- COMPLEX PUBLIC METHODS
	public String getMailAdministrators() {
		return toStrList(mailAdministrators, ",");
	}
	public List<String> getMailAdministratorsAsList() {
		return mailAdministrators;
	}
	public String[] getMailAdministratorsAsArray() {
		return Conversion.toArray(toStrList(mailAdministrators, ","), ",");
	}
	public void setMailAdministrators(String mailAdministratorsStr) {
		this.mailAdministrators = toList(mailAdministratorsStr, ",");
	}

	// --------------------------------------------------------- COMPLEX PUBLIC METHODS
    /**
     * Returns a String list of objects separated by the given separator 
     * @return null if list or separator is null
     */
    public static String toStrList(Collection<?> list,String separator) {
        String output=null;
        if(list!=null && separator!=null) {
            output=list.toString().replaceAll("\\[", "").replaceAll("\\]","");
            output=output.replaceAll("\\, ", separator);
        }
        return output;
    }
    
    public static List<String> toList(String str, String separator) {
		List<String> list = new ArrayList<String>();
		if(!Conversion.isNullOrEmpty(str)){
			list = Arrays.asList(str.split(separator));
		}
    	return list;
    }
    
}
